package com.bonus.canteen.core.kitchen.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.kitchen.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.kitchen.domain.KitchenStaffDevicePrivilege;
import com.bonus.canteen.core.kitchen.service.IKitchenStaffDevicePrivilegeService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 厨房员工设备权限Controller
 * 
 * @author xsheng
 * @date 2025-06-17
 */
@Api(tags = "厨房员工设备权限接口")
@RestController
@RequestMapping("/kitchen_staff_device_privilege")
public class KitchenStaffDevicePrivilegeController extends BaseController {
    @Autowired
    private IKitchenStaffDevicePrivilegeService kitchenStaffDevicePrivilegeService;

    /**
     * 查询厨房员工设备权限列表
     */
    @ApiOperation(value = "查询厨房员工设备权限列表")
    //@RequiresPermissions("kitchen:privilege:list")
    @PostMapping("/list")
    public TableDataInfo list(@RequestBody @Valid KitchenStaffDevicePrivilege kitchenStaffDevicePrivilege) {
        startPage();
        List<KitchenStaffDevicePrivilege> list = kitchenStaffDevicePrivilegeService.selectKitchenStaffDevicePrivilegeList(kitchenStaffDevicePrivilege);
        return getDataTable(list);
    }

    /**
     * 导出厨房员工设备权限列表
     */
    @ApiOperation(value = "导出厨房员工设备权限列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:privilege:export")
    @SysLog(title = "厨房员工设备权限", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出厨房员工设备权限")
    @PostMapping("/export")
    public void export(HttpServletResponse response, KitchenStaffDevicePrivilege kitchenStaffDevicePrivilege) {
        List<KitchenStaffDevicePrivilege> list = kitchenStaffDevicePrivilegeService.selectKitchenStaffDevicePrivilegeList(kitchenStaffDevicePrivilege);
        ExcelUtil<KitchenStaffDevicePrivilege> util = new ExcelUtil<KitchenStaffDevicePrivilege>(KitchenStaffDevicePrivilege.class);
        util.exportExcel(response, list, "厨房员工设备权限数据");
    }

    /**
     * 获取厨房员工设备权限详细信息
     */
    @ApiOperation(value = "获取厨房员工设备权限详细信息")
    //@RequiresPermissions("kitchen:privilege:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(kitchenStaffDevicePrivilegeService.selectKitchenStaffDevicePrivilegeById(id));
    }

    /**
     * 新增厨房员工设备权限
     */
    @ApiOperation(value = "新增厨房员工设备权限")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:privilege:add")
    @SysLog(title = "厨房员工设备权限", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增厨房员工设备权限")
    @PostMapping
    public AjaxResult add(@RequestBody List<KitchenStaffDevicePrivilege> kitchenStaffDevicePrivilege) {
        try {
            return toAjax(kitchenStaffDevicePrivilegeService.insertKitchenStaffDevicePrivilege(kitchenStaffDevicePrivilege));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改厨房员工设备权限
     */
    @ApiOperation(value = "修改厨房员工设备权限")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:privilege:edit")
    @SysLog(title = "厨房员工设备权限", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改厨房员工设备权限")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody List<KitchenStaffDevicePrivilege> kitchenStaffDevicePrivilege) {
        try {
            return toAjax(kitchenStaffDevicePrivilegeService.updateKitchenStaffDevicePrivilege(kitchenStaffDevicePrivilege));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除厨房员工设备权限
     */
    @ApiOperation(value = "删除厨房员工设备权限")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:privilege:remove")
    @SysLog(title = "厨房员工设备权限", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除厨房员工设备权限")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(kitchenStaffDevicePrivilegeService.deleteKitchenStaffDevicePrivilegeByIds(ids));
    }
}
